@@ -61,7 +61,6 @@ import org.springframework.data.jpa.domain.Specification;
 import org.springframework.stereotype.Component;
 import org.springframework.util.CollectionUtils;
 
-
 /**
  * Calculate alarms based on the alarm definition rules and collected data
  */
@@ -70,6 +69,8 @@ import org.springframework.util.CollectionUtils;
 public class CalculateAlarm {
 
     private static final String SYSTEM_VALUE_ROW_COUNT = "system_value_row_count";
+    
+    private static final int CALCULATE_THREADS = 3;
 
     /**
      * The alarm in the process is triggered
@@ -124,15 +125,15 @@ public class CalculateAlarm {
                         calculate(metricsData);
                     }
                 } catch (InterruptedException ignored) {
-
+                    Thread.currentThread().interrupt();
                 } catch (Exception e) {
                     log.error("calculate alarm error: {}.", e.getMessage(), e);
                 }
             }
         };
-        workerPool.executeJob(runnable);
-        workerPool.executeJob(runnable);
-        workerPool.executeJob(runnable);
+        for (int i = 0; i < CALCULATE_THREADS; i++) {
+            workerPool.executeJob(runnable);
+        }
     }
 
     private void calculate(CollectRep.MetricsData metricsData) {
