@@ -21,13 +21,13 @@ import static org.junit.jupiter.api.Assertions.assertDoesNotThrow;
 import static org.junit.jupiter.api.Assertions.assertEquals;
 import static org.junit.jupiter.api.Assertions.assertNotNull;
 import static org.junit.jupiter.api.Assertions.assertThrows;
+import static org.mockito.Mockito.any;
 import static org.mockito.Mockito.doNothing;
-import static org.mockito.Mockito.mock;
+import static org.mockito.Mockito.doReturn;
 import static org.mockito.Mockito.reset;
 import static org.mockito.Mockito.spy;
 import static org.mockito.Mockito.when;
 import java.util.ArrayList;
-import java.util.Arrays;
 import java.util.Collections;
 import java.util.HashMap;
 import java.util.HashSet;
@@ -196,7 +196,7 @@ class MonitorServiceTest {
         when(monitorDao.save(monitor)).thenReturn(monitor);
         List<Param> params = Collections.singletonList(new Param());
         when(paramDao.saveAll(params)).thenReturn(params);
-        assertDoesNotThrow(() -> monitorService.addMonitor(monitor, params, null));
+        assertDoesNotThrow(() -> monitorService.addMonitor(monitor, params, null, null));
     }
 
     @Test
@@ -211,7 +211,7 @@ class MonitorServiceTest {
         when(collectJobScheduling.addAsyncCollectJob(job, null)).thenReturn(1L);
         List<Param> params = Collections.singletonList(new Param());
         when(monitorDao.save(monitor)).thenThrow(RuntimeException.class);
-        assertThrows(MonitorDatabaseException.class, () -> monitorService.addMonitor(monitor, params, null));
+        assertThrows(MonitorDatabaseException.class, () -> monitorService.addMonitor(monitor, params, null, null));
     }
 
     /**
@@ -587,7 +587,7 @@ class MonitorServiceTest {
         dto.setMonitor(monitor);
         when(monitorDao.findById(monitorId)).thenReturn(Optional.empty());
         try {
-            monitorService.modifyMonitor(dto.getMonitor(), dto.getParams(), null);
+            monitorService.modifyMonitor(dto.getMonitor(), dto.getParams(), null, null);
         } catch (IllegalArgumentException e) {
             assertEquals("The Monitor " + monitorId + " not exists", e.getMessage());
         }
@@ -598,7 +598,7 @@ class MonitorServiceTest {
         Monitor existErrorMonitor = Monitor.builder().app("app2").name("memory").host("host").id(monitorId).build();
         when(monitorDao.findById(monitorId)).thenReturn(Optional.of(existErrorMonitor));
         try {
-            monitorService.modifyMonitor(dto.getMonitor(), dto.getParams(), null);
+            monitorService.modifyMonitor(dto.getMonitor(), dto.getParams(), null, null);
         } catch (IllegalArgumentException e) {
             assertEquals("Can not modify monitor's app type", e.getMessage());
         }
@@ -607,7 +607,7 @@ class MonitorServiceTest {
         when(monitorDao.findById(monitorId)).thenReturn(Optional.of(existOkMonitor));
         when(monitorDao.save(monitor)).thenThrow(RuntimeException.class);
 
-        assertThrows(MonitorDatabaseException.class, () -> monitorService.modifyMonitor(dto.getMonitor(), dto.getParams(), null));
+        assertThrows(MonitorDatabaseException.class, () -> monitorService.modifyMonitor(dto.getMonitor(), dto.getParams(), null, null));
     }
 
     @Test
@@ -652,9 +652,8 @@ class MonitorServiceTest {
 
     @Test
     void getMonitors() {
-        Specification<Monitor> specification = mock(Specification.class);
-        when(monitorDao.findAll(specification, PageRequest.of(1, 1))).thenReturn(Page.empty());
-        assertNotNull(monitorService.getMonitors(specification, PageRequest.of(1, 1)));
+        doReturn(Page.empty()).when(monitorDao).findAll(any(Specification.class), any(PageRequest.class));
+        assertNotNull(monitorService.getMonitors(null, null, null, null, null, "gmtCreate", "desc", 1, 1, null));
     }
 
     @Test
@@ -742,7 +741,7 @@ class MonitorServiceTest {
         when(appService.getAppDefine(monitor.getApp())).thenReturn(job);
 
         List<Param> params = Collections.singletonList(new Param());
-        List<String> metrics = Arrays.asList();
+        List<String> metrics = List.of();
         try {
             monitorService.addNewMonitorOptionalMetrics(metrics, monitor, params);
         } catch (MonitorMetricsException e) {
@@ -750,7 +749,7 @@ class MonitorServiceTest {
         }
         reset();
         when(monitorDao.save(monitor)).thenThrow(RuntimeException.class);
-        metrics = Arrays.asList("metric-001");
+        metrics = List.of("metric-001");
         List<Metrics> metricsDefine = new ArrayList<>();
         Metrics e = new Metrics();
         e.setName("metric-001");
