@@ -40,6 +40,8 @@ import lombok.extern.slf4j.Slf4j;
 import org.apache.commons.codec.binary.Base64;
 import org.apache.commons.lang3.math.NumberUtils;
 import org.apache.hertzbeat.common.constants.CommonConstants;
+import org.apache.hertzbeat.common.constants.NetworkConstants;
+import org.apache.hertzbeat.common.constants.SignConstants;
 import org.apache.hertzbeat.common.entity.dto.Value;
 import org.apache.hertzbeat.common.entity.message.CollectRep;
 import org.apache.hertzbeat.common.util.CommonUtil;
@@ -58,6 +60,8 @@ import org.springframework.util.StringUtils;
 import org.springframework.web.client.RestTemplate;
 import org.springframework.web.util.UriComponentsBuilder;
 
+import static org.apache.hertzbeat.common.constants.ConfigConstants.FunctionModuleConstants.STATUS;
+
 /**
  * tdengine data storage
  */
@@ -70,14 +74,12 @@ public class VictoriaMetricsClusterDataStorage extends AbstractHistoryDataStorag
     private static final String IMPORT_PATH = "/api/v1/import";
     private static final String EXPORT_PATH = "/api/v1/export";
     private static final String STATUS_PATH = "/api/v1/status/tsdb";
-    private static final String STATUS = "status";
     private static final String STATUS_SUCCESS = "success";
     private static final String QUERY_RANGE_PATH = "/api/v1/query_range";
     private static final String LABEL_KEY_NAME = "__name__";
     private static final String LABEL_KEY_JOB = "job";
     private static final String LABEL_KEY_INSTANCE = "instance";
     private static final String SPILT = "_";
-    private static final String BASIC = "Basic";
     private static final String MONITOR_METRICS_KEY = "__metrics__";
     private static final String MONITOR_METRIC_KEY = "__metric__";
 
@@ -177,7 +179,8 @@ public class VictoriaMetricsClusterDataStorage extends AbstractHistoryDataStorag
                             String encodedAuth = new String(
                                     Base64.encodeBase64(authStr.getBytes(StandardCharsets.UTF_8)),
                                     StandardCharsets.UTF_8);
-                            headers.add(HttpHeaders.AUTHORIZATION, BASIC + " " + encodedAuth);
+                            headers.add(HttpHeaders.AUTHORIZATION, NetworkConstants.BASIC
+                                    + SignConstants.BLANK + encodedAuth);
                         }
                         HttpEntity<VictoriaMetricsContent> httpEntity = new HttpEntity<>(content, headers);
                         ResponseEntity<String> responseEntity = restTemplate.postForEntity(
@@ -219,7 +222,8 @@ public class VictoriaMetricsClusterDataStorage extends AbstractHistoryDataStorag
                 String authStr = vmSelectProps.username() + ":" + vmSelectProps.password();
                 String encodedAuth = new String(Base64.encodeBase64(authStr.getBytes(StandardCharsets.UTF_8)),
                         StandardCharsets.UTF_8);
-                headers.add(HttpHeaders.AUTHORIZATION, BASIC + " " + encodedAuth);
+                headers.add(HttpHeaders.AUTHORIZATION, NetworkConstants.BASIC
+                        + SignConstants.BLANK + encodedAuth);
             }
             HttpEntity<Void> httpEntity = new HttpEntity<>(headers);
             URI uri = UriComponentsBuilder.fromHttpUrl(vmSelectProps.url() + EXPORT_PATH)
@@ -274,9 +278,12 @@ public class VictoriaMetricsClusterDataStorage extends AbstractHistoryDataStorag
     public Map<String, List<Value>> getHistoryIntervalMetricData(Long monitorId, String app, String metrics,
             String metric, String label, String history) {
         if (!serverAvailable) {
-            log.error("\n\t---------------VictoriaMetrics Init Failed---------------\n"
-                    + "\t--------------Please Config VictoriaMetrics--------------\n"
-                    + "\t----------Can Not Use Metric History Now----------\n");
+            log.error("""
+                    
+                    \t---------------VictoriaMetrics Init Failed---------------
+                    \t--------------Please Config VictoriaMetrics--------------
+                    \t----------Can Not Use Metric History Now----------
+                    """);
             return Collections.emptyMap();
         }
         long endTime = ZonedDateTime.now().toEpochSecond();
@@ -311,7 +318,8 @@ public class VictoriaMetricsClusterDataStorage extends AbstractHistoryDataStorag
                 String authStr = vmSelectProps.username() + ":" + vmSelectProps.password();
                 String encodedAuth = new String(Base64.encodeBase64(authStr.getBytes(StandardCharsets.UTF_8)),
                         StandardCharsets.UTF_8);
-                headers.add(HttpHeaders.AUTHORIZATION, BASIC + " " + encodedAuth);
+                headers.add(HttpHeaders.AUTHORIZATION, NetworkConstants.BASIC
+                        + SignConstants.BLANK + encodedAuth);
             }
             HttpEntity<Void> httpEntity = new HttpEntity<>(headers);
             URI uri = UriComponentsBuilder.fromHttpUrl(vmSelectProps.url() + QUERY_RANGE_PATH)
