@@ -17,7 +17,6 @@
 
 package org.apache.hertzbeat.warehouse.store.history.vm;
 
-import com.fasterxml.jackson.databind.JsonNode;
 import java.math.BigDecimal;
 import java.math.RoundingMode;
 import java.net.URI;
@@ -40,6 +39,8 @@ import lombok.extern.slf4j.Slf4j;
 import org.apache.commons.codec.binary.Base64;
 import org.apache.commons.lang3.math.NumberUtils;
 import org.apache.hertzbeat.common.constants.CommonConstants;
+import org.apache.hertzbeat.common.constants.NetworkConstants;
+import org.apache.hertzbeat.common.constants.SignConstants;
 import org.apache.hertzbeat.common.entity.dto.Value;
 import org.apache.hertzbeat.common.entity.message.CollectRep;
 import org.apache.hertzbeat.common.util.CommonUtil;
@@ -76,13 +77,10 @@ public class VictoriaMetricsDataStorage extends AbstractHistoryDataStorage {
     private static final String EXPORT_PATH = "/api/v1/export";
     private static final String QUERY_RANGE_PATH = "/api/v1/query_range";
     private static final String STATUS_PATH = "/api/v1/status/tsdb";
-    private static final String STATUS = "status";
-    private static final String STATUS_SUCCESS = "success";
     private static final String LABEL_KEY_NAME = "__name__";
     private static final String LABEL_KEY_JOB = "job";
     private static final String LABEL_KEY_INSTANCE = "instance";
     private static final String SPILT = "_";
-    private static final String BASIC = "Basic";
     private static final String MONITOR_METRICS_KEY = "__metrics__";
     private static final String MONITOR_METRIC_KEY = "__metric__";
 
@@ -103,13 +101,21 @@ public class VictoriaMetricsDataStorage extends AbstractHistoryDataStorage {
     private boolean checkVictoriaMetricsDatasourceAvailable() {
         // check server status
         try {
-            String result = restTemplate.getForObject(victoriaMetricsProp.url() + STATUS_PATH, String.class);
-
-            JsonNode jsonNode = JsonUtil.fromJson(result);
-            if (jsonNode != null && STATUS_SUCCESS.equalsIgnoreCase(jsonNode.get(STATUS).asText())) {
+            HttpHeaders headers = new HttpHeaders();
+            if (StringUtils.hasText(victoriaMetricsProp.username())
+                    && StringUtils.hasText(victoriaMetricsProp.password())) {
+                String authStr = victoriaMetricsProp.username() + SignConstants.DOUBLE_MARK + victoriaMetricsProp.password();
+                String encodedAuth = new String(Base64.encodeBase64(authStr.getBytes(StandardCharsets.UTF_8)), StandardCharsets.UTF_8);
+                headers.add(HttpHeaders.AUTHORIZATION,  NetworkConstants.BASIC + " " + encodedAuth);
+            }
+            HttpEntity<Void> httpEntity = new HttpEntity<>(headers);
+            ResponseEntity<String> responseEntity = restTemplate.exchange(victoriaMetricsProp.url() + STATUS_PATH,
+                    HttpMethod.GET, httpEntity, String.class);
+            if (responseEntity.getStatusCode().is2xxSuccessful()) {
+                log.info("check victoria metrics server status success.");
                 return true;
             }
-            log.error("check victoria metrics server status not success: {}.", result);
+            log.error("check victoria metrics server status not success: {}.", responseEntity.getBody());
         } catch (Exception e) {
             log.error("check victoria metrics server status error: {}.", e.getMessage());
         }
@@ -178,9 +184,10 @@ public class VictoriaMetricsDataStorage extends AbstractHistoryDataStorage {
                         headers.setContentType(MediaType.APPLICATION_JSON);
                         if (StringUtils.hasText(victoriaMetricsProp.username())
                                 && StringUtils.hasText(victoriaMetricsProp.password())) {
-                            String authStr = victoriaMetricsProp.username() + ":" + victoriaMetricsProp.password();
+                            String authStr = victoriaMetricsProp.username() + SignConstants.DOUBLE_MARK + victoriaMetricsProp.password();
                             String encodedAuth = new String(Base64.encodeBase64(authStr.getBytes(StandardCharsets.UTF_8)), StandardCharsets.UTF_8);
-                            headers.add(HttpHeaders.AUTHORIZATION,  BASIC + " " + encodedAuth);
+                            headers.add(HttpHeaders.AUTHORIZATION,  NetworkConstants.BASIC
+                                    + SignConstants.BLANK + encodedAuth);
                         }
                         HttpEntity<VictoriaMetricsContent> httpEntity = new HttpEntity<>(content, headers);
                         ResponseEntity<String> responseEntity = restTemplate.postForEntity(victoriaMetricsProp.url() + IMPORT_PATH,
@@ -220,7 +227,7 @@ public class VictoriaMetricsDataStorage extends AbstractHistoryDataStorage {
                     && StringUtils.hasText(victoriaMetricsProp.password())) {
                 String authStr = victoriaMetricsProp.username() + ":" + victoriaMetricsProp.password();
                 String encodedAuth = new String(Base64.encodeBase64(authStr.getBytes(StandardCharsets.UTF_8)), StandardCharsets.UTF_8);
-                headers.add(HttpHeaders.AUTHORIZATION,  BASIC + " " + encodedAuth);
+                headers.add(HttpHeaders.AUTHORIZATION,  NetworkConstants.BASIC + SignConstants.BLANK + encodedAuth);
             }
             HttpEntity<Void> httpEntity = new HttpEntity<>(headers);
             URI uri = UriComponentsBuilder.fromHttpUrl(victoriaMetricsProp.url() + EXPORT_PATH)
@@ -274,9 +281,12 @@ public class VictoriaMetricsDataStorage extends AbstractHistoryDataStorage {
     public Map<String, List<Value>> getHistoryIntervalMetricData(Long monitorId, String app, String metrics,
                                                                  String metric, String label, String history) {
         if (!serverAvailable) {
-            log.error("\n\t---------------VictoriaMetrics Init Failed---------------\n"
-                    + "\t--------------Please Config VictoriaMetrics--------------\n"
-                    + "\t----------Can Not Use Metric History Now----------\n");
+            log.error("""
+                    
+                    \t---------------VictoriaMetrics Init Failed---------------
+                    \t--------------Please Config VictoriaMetrics--------------
+                    \t----------Can Not Use Metric History Now----------
+                    """);
             return Collections.emptyMap();
         }
         long endTime = ZonedDateTime.now().toEpochSecond();
@@ -311,7 +321,8 @@ public class VictoriaMetricsDataStorage extends AbstractHistoryDataStorage {
                     && StringUtils.hasText(victoriaMetricsProp.password())) {
                 String authStr = victoriaMetricsProp.username() + ":" + victoriaMetricsProp.password();
                 String encodedAuth = new String(Base64.encodeBase64(authStr.getBytes(StandardCharsets.UTF_8)), StandardCharsets.UTF_8);
-                headers.add(HttpHeaders.AUTHORIZATION,  BASIC + " " + encodedAuth);
+                headers.add(HttpHeaders.AUTHORIZATION,  NetworkConstants.BASIC
+                        + SignConstants.BLANK + encodedAuth);
             }
             HttpEntity<Void> httpEntity = new HttpEntity<>(headers);
             URI uri = UriComponentsBuilder.fromHttpUrl(victoriaMetricsProp.url() + QUERY_RANGE_PATH)
