@@ -17,7 +17,7 @@
  * under the License.
  */
 
-import { HttpClient, HttpParams } from '@angular/common/http';
+import { HttpClient } from '@angular/common/http';
 import { Injectable } from '@angular/core';
 import { Observable } from 'rxjs';
 
@@ -32,6 +32,9 @@ export class AuthService {
   constructor(private http: HttpClient) {}
 
   public refreshToken(refreshToken: string): Observable<Message<any>> {
-    return this.http.get<Message<any>>(`${account_auth_refresh_uri}/${refreshToken}`);
+    let body = {
+      token: refreshToken
+    };
+    return this.http.post<Message<any>>(`${account_auth_refresh_uri}`, body);
   }
 }
